package de.hft.stuttgart.citydoctor2.healing;

import java.io.IOException;

import org.junit.Assert;
import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.check.Checker;
import de.hft.stuttgart.citydoctor2.check.ValidationConfiguration;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.healer.Healer;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParseException;
import de.hft.stuttgart.citydoctor2.parser.InvalidGmlFileException;

public class HealConsecutivePointsSameErrorTest {

	@Test
	public void test() throws CityGmlParseException, IOException, InvalidGmlFileException {
		String path = "src/test/resources/SimpleSolid_SrefBS-GE-gml-LR-0002-T0001.gml";
		ValidationConfiguration config = ValidationConfiguration.loadStandardValidationConfig();
		// disable schematron testing
		config.setSchematronFilePathInGlobalParameters(null);
		CityDoctorModel model = TestUtil.loadCityModel(path, config);
		Checker c = new Checker(config, model);
		c.runChecks();
	
		Geometry geom = model.getBuildings().get(0).getGeometries().get(0);
		Assert.assertTrue(geom.containsError(CheckId.C_GE_R_DUPLICATE_POINT));
		
		Healer healer = new Healer(c);
		healer.healCityObject(model.getBuildings().get(0));
		Assert.assertFalse(geom.containsError(CheckId.C_GE_R_DUPLICATE_POINT));
	}

}
